@@ -7,7 +7,7 @@ package conf;  # Don't remove this line!
 #
 # Administrator's email address
 #
-$ADDRESS = 'webmaster@binhost-amd64-x86-64-v3-server-23.gentoo.org';
+$ADDRESS = 'webmaster@binhost-amd64-x86-64-v3-kde-23.gentoo.org';
 
 
 #===================================================================
@@ -204,7 +204,7 @@ $NKF = "no";
 # KAKASI 2.x or later
 # Text::Kakasi 1.05 or later
 #
-$KAKASI = "no";
+$KAKASI = "/usr/bin/kakasi -ieuc -oeuc -w";
 
 #
 # ChaSen 2.02 or later (simple wakatigaki)
@@ -225,7 +225,7 @@ $MECAB = "no";
 #
 # Default Japanese processer: KAKASI or ChaSen or MeCab.
 #
-$WAKATI  = $none;
+$WAKATI  = $KAKASI;
 
 
 #===================================================================
